@@ -13,52 +13,60 @@
 #
 # Copyright Buildbot Team Members
 
+import glob
 import os
-import sys
 import shutil
+import sys
 
-from twisted.internet import threads, defer
-from twisted.python import runtime, log
+from twisted.internet import defer
+from twisted.internet import threads
+from twisted.python import log
+from twisted.python import runtime
 
 from buildslave import runprocess
-from buildslave.commands import base, utils
+from buildslave.commands import base
+from buildslave.commands import utils
+
 
 class MakeDirectory(base.Command):
 
     header = "mkdir"
 
+    # args['dir'] is relative to Builder directory, and is required.
+    requiredArgs = ['dir']
+
     def start(self):
-        args = self.args
-        # args['dir'] is relative to Builder directory, and is required.
-        assert args['dir'] is not None
-        dirname = os.path.join(self.builder.basedir, args['dir'])
+        dirname = os.path.join(self.builder.basedir, self.args['dir'])
 
         try:
             if not os.path.isdir(dirname):
                 os.makedirs(dirname)
             self.sendStatus({'rc': 0})
-        except:
-            self.sendStatus({'rc': 1})
+        except OSError, e:
+            log.msg("MakeDirectory %s failed" % dirname, e)
+            self.sendStatus({'header': '%s: %s: %s' % (self.header, e.strerror, dirname)})
+            self.sendStatus({'rc': e.errno})
+
 
 class RemoveDirectory(base.Command):
 
     header = "rmdir"
 
-    def setup(self,args):
-        self.logEnviron = args.get('logEnviron',True)
+    # args['dir'] is relative to Builder directory, and is required.
+    requiredArgs = ['dir']
 
+    def setup(self, args):
+        self.logEnviron = args.get('logEnviron', True)
 
     @defer.deferredGenerator
     def start(self):
         args = self.args
-        # args['dir'] is relative to Builder directory, and is required.
-        assert args['dir'] is not None
         dirnames = args['dir']
 
         self.timeout = args.get('timeout', 120)
         self.maxTime = args.get('maxTime', None)
         self.rc = 0
-        if type(dirnames) is list:
+        if isinstance(dirnames, list):
             assert len(dirnames) != 0
             for dirname in dirnames:
                 wfd = defer.waitForDeferred(self.removeSingleDir(dirname))
@@ -80,22 +88,24 @@ class RemoveDirectory(base.Command):
         self.dir = os.path.join(self.builder.basedir, dirname)
         if runtime.platformType != "posix":
             d = threads.deferToThread(utils.rmdirRecursive, self.dir)
+
             def cb(_):
-                return 0 # rc=0
+                return 0  # rc=0
+
             def eb(f):
-                self.sendStatus({'header' : 'exception from rmdirRecursive\n' + f.getTraceback()})
-                return -1 # rc=-1
+                self.sendStatus({'header': 'exception from rmdirRecursive\n' + f.getTraceback()})
+                return -1  # rc=-1
             d.addCallbacks(cb, eb)
         else:
             d = self._clobber(None)
 
         return d
 
-    def _clobber(self, dummy, chmodDone = False):
+    def _clobber(self, dummy, chmodDone=False):
         command = ["rm", "-rf", self.dir]
         c = runprocess.RunProcess(self.builder, command, self.builder.basedir,
-                         sendRC=0, timeout=self.timeout, maxTime=self.maxTime,
-                         logEnviron=self.logEnviron, usePTY=False)
+                                  sendRC=0, timeout=self.timeout, maxTime=self.maxTime,
+                                  logEnviron=self.logEnviron, usePTY=False)
 
         self.command = c
         # sendRC=0 means the rm command will send stdout/stderr to the
@@ -121,47 +131,50 @@ class RemoveDirectory(base.Command):
             # directory for which it doesn't have permission, before changing that
             # permission) by running 'find' instead
             command = ["find", os.path.join(self.builder.basedir, self.dir),
-                                '-exec', 'chmod', 'u+rwx', '{}', ';' ]
+                       '-exec', 'chmod', 'u+rwx', '{}', ';']
         c = runprocess.RunProcess(self.builder, command, self.builder.basedir,
-                         sendRC=0, timeout=self.timeout, maxTime=self.maxTime,
-                         logEnviron=self.logEnviron, usePTY=False)
+                                  sendRC=0, timeout=self.timeout, maxTime=self.maxTime,
+                                  logEnviron=self.logEnviron, usePTY=False)
 
         self.command = c
         d = c.start()
         d.addCallback(lambda dummy: self._clobber(dummy, True))
         return d
 
+
 class CopyDirectory(base.Command):
 
     header = "cpdir"
 
-    def setup(self,args):
-        self.logEnviron = args.get('logEnviron',True)
-        
+    # args['todir'] and args['fromdir'] are relative to Builder directory, and are required.
+    requiredArgs = ['todir', 'fromdir']
+
+    def setup(self, args):
+        self.logEnviron = args.get('logEnviron', True)
+
     def start(self):
         args = self.args
-        # args['todir'] is relative to Builder directory, and is required.
-        # args['fromdir'] is relative to Builder directory, and is required.
-        assert args['todir'] is not None
-        assert args['fromdir'] is not None
 
-        fromdir = os.path.join(self.builder.basedir, args['fromdir'])
-        todir = os.path.join(self.builder.basedir, args['todir'])
+        fromdir = os.path.join(self.builder.basedir, self.args['fromdir'])
+        todir = os.path.join(self.builder.basedir, self.args['todir'])
 
         self.timeout = args.get('timeout', 120)
         self.maxTime = args.get('maxTime', None)
 
         if runtime.platformType != "posix":
             d = threads.deferToThread(shutil.copytree, fromdir, todir)
+
             def cb(_):
-                return 0 # rc=0
+                return 0  # rc=0
+
             def eb(f):
-                self.sendStatus({'header' : 'exception from copytree\n' + f.getTraceback()})
-                return -1 # rc=-1
+                self.sendStatus({'header': 'exception from copytree\n' + f.getTraceback()})
+                return -1  # rc=-1
             d.addCallbacks(cb, eb)
+
             @d.addCallback
             def send_rc(rc):
-                self.sendStatus({'rc' : rc})
+                self.sendStatus({'rc': rc})
         else:
             if not os.path.exists(os.path.dirname(todir)):
                 os.makedirs(os.path.dirname(todir))
@@ -171,8 +184,8 @@ class CopyDirectory(base.Command):
 
             command = ['cp', '-R', '-P', '-p', '-v', fromdir, todir]
             c = runprocess.RunProcess(self.builder, command, self.builder.basedir,
-                             sendRC=False, timeout=self.timeout, maxTime=self.maxTime,
-                             logEnviron=self.logEnviron, usePTY=False)
+                                      sendRC=False, timeout=self.timeout, maxTime=self.maxTime,
+                                      logEnviron=self.logEnviron, usePTY=False)
             self.command = c
             d = c.start()
             d.addCallback(self._abandonOnFailure)
@@ -180,19 +193,62 @@ class CopyDirectory(base.Command):
             d.addCallbacks(self._sendRC, self._checkAbandoned)
         return d
 
+
 class StatFile(base.Command):
 
     header = "stat"
 
+    # args['file'] is relative to Builder directory, and is required.
+    requireArgs = ['file']
+
     def start(self):
-        args = self.args
-        # args['dir'] is relative to Builder directory, and is required.
-        assert args['file'] is not None
-        filename = os.path.join(self.builder.basedir, args['file'])
+        filename = os.path.join(self.builder.basedir, self.args['file'])
 
         try:
             stat = os.stat(filename)
             self.sendStatus({'stat': tuple(stat)})
             self.sendStatus({'rc': 0})
-        except:
-            self.sendStatus({'rc': 1})
+        except OSError, e:
+            log.msg("StatFile %s failed" % filename, e)
+            self.sendStatus({'header': '%s: %s: %s' % (self.header, e.strerror, filename)})
+            self.sendStatus({'rc': e.errno})
+
+
+class GlobPath(base.Command):
+
+    header = "glob"
+
+    # args['path'] is relative to Builder directory, and is required.
+    requiredArgs = ['path']
+
+    def start(self):
+        pathname = os.path.join(self.builder.basedir, self.args['path'])
+
+        try:
+            files = glob.glob(pathname)
+            self.sendStatus({'files': files})
+            self.sendStatus({'rc': 0})
+        except OSError, e:
+            log.msg("GlobPath %s failed" % pathname, e)
+            self.sendStatus({'header': '%s: %s: %s' % (self.header, e.strerror, pathname)})
+            self.sendStatus({'rc': e.errno})
+
+
+class ListDir(base.Command):
+
+    header = "listdir"
+
+    # args['dir'] is relative to Builder directory, and is required.
+    requireArgs = ['dir']
+
+    def start(self):
+        dirname = os.path.join(self.builder.basedir, self.args['dir'])
+
+        try:
+            files = os.listdir(dirname)
+            self.sendStatus({'files': files})
+            self.sendStatus({'rc': 0})
+        except OSError, e:
+            log.msg("ListDir %s failed" % dirname, e)
+            self.sendStatus({'header': '%s: %s: %s' % (self.header, e.strerror, dirname)})
+            self.sendStatus({'rc': e.errno})
