@@ -15,6 +15,7 @@
 
 import os
 
+
 def isBuildslaveDir(dir):
     def print_error(error_message):
         print "%s\ninvalid buildslave directory '%s'" % (error_message, dir)
@@ -23,8 +24,8 @@ def isBuildslaveDir(dir):
     try:
         contents = open(buildbot_tac).read()
     except IOError, exception:
-        print_error("error reading '%s': %s" % \
-                       (buildbot_tac, exception.strerror))
+        print_error("error reading '%s': %s" %
+                    (buildbot_tac, exception.strerror))
         return False
 
     if "Application('buildslave')" not in contents:
